{ "ABS", kwABS },
{ "ACTION", kwACTION },
{ "ACTIVE", kwACTIVE },
{ "ADD", kwADD },
{ "ADMIN", kwADMIN },
{ "AFTER", kwAFTER },
{ "ALL", kwALL },
{ "ALTER", kwALTER },
{ "AND", kwAND },
{ "ANY", kwANY },
{ "AS", kwAS },
{ "ASC", kwASCENDING },
{ "ASCENDING", kwASCENDING },
{ "AT", kwAT },
{ "AUTO", kwAUTO },
{ "AUTODDL", kwAUTODDL },
{ "AVG", kwAVG },
{ "BACKUP", kwBACKUP },            // fb2.0
{ "BASED", kwBASED },
{ "BASENAME", kwBASENAME },
{ "BEFORE", kwBEFORE },
{ "BEGIN", kwBEGIN },
{ "BETWEEN", kwBETWEEN },
{ "BIGINT", kwBIGINT },
{ "BIT_LENGTH", kwBIT_LENGTH },    // fb2.0
{ "BLOB", kwBLOB },
{ "BLOBEDIT", kwBLOBEDIT },
{ "BLOCK", kwBLOCK },              // fb2.0
{ "BOOLEAN", kwBOOLEAN },
{ "BOTH", kwBOTH },                // fb2.0
{ "BREAK", kwBREAK },
{ "BUFFER", kwBUFFER },
{ "BY", kwBY },
{ "CACHE", kwCACHE },
{ "CASCADE", kwCASCADE },
{ "CASE", kwCASE },
{ "CAST", kwCAST },
{ "CHAR", kwCHAR },                // fb2.0
{ "CHARACTER", kwCHARACTER },
{ "CHARACTER_LENGTH", kwCHARACTER_LENGTH },    // fb2.0
{ "CHAR_LENGTH", kwCHAR_LENGTH },
{ "CHECK", kwCHECK },
{ "CHECK_POINT_LEN", kwCHECK_POINT_LEN },
{ "CLOSE", kwCLOSE },                              // fb2.0
{ "COALESCE", kwCOALESCE },
{ "COLLATE", kwCOLLATE },
{ "COLLATION", kwCOLLATION },
{ "COLUMN", kwCOLUMN },
{ "COMMENT", kwCOMMENT },
{ "COMMIT", kwCOMMIT },
{ "COMMITTED", kwCOMMITTED },
{ "COMPILETIME", kwCOMPILETIME },
{ "COMPUTED", kwCOMPUTED },
{ "CONDITIONAL", kwCONDITIONAL },
{ "CONNECT", kwCONNECT },
{ "CONSTRAINT", kwCONSTRAINT },
{ "CONTAINING", kwCONTAINING },
{ "CONTINUE", kwCONTINUE },
{ "COUNT", kwCOUNT },
{ "CREATE", kwCREATE },
{ "CROSS", kwCROSS },          // fb2.0
{ "CSTRING", kwCSTRING },
{ "CURRENT", kwCURRENT },
{ "CURRENT_CONNECTION", kwCURRENT_CONNECTION },
{ "CURRENT_DATE", kwCURRENT_DATE },
{ "CURRENT_ROLE", kwCURRENT_ROLE },
{ "CURRENT_TIME", kwCURRENT_TIME },
{ "CURRENT_TIMESTAMP", kwCURRENT_TIMESTAMP },
{ "CURRENT_TRANSACTION", kwCURRENT_TRANSACTION },
{ "CURRENT_USER", kwCURRENT_USER },
{ "CURSOR", kwCURSOR },
{ "DATABASE", kwDATABASE },
{ "DATE", kwDATE },
{ "DAY", kwDAY },
{ "DB_KEY", kwDB_KEY },
{ "DEC", kwDEC },
{ "DECIMAL", kwDECIMAL },
{ "DECLARE", kwDECLARE },
{ "DEFAULT", kwDEFAULT },
{ "DELETE", kwDELETE },
{ "DELETING", kwDELETING },
{ "DESC", kwDESCENDING },
{ "DESCENDING", kwDESCENDING },
{ "DESCRIBE", kwDESCRIBE },
{ "DESCRIPTOR", kwDESCRIPTOR },
{ "DIFFERENCE", kwDIFFERENCE }, // fb2.0
{ "DISCONNECT", kwDISCONNECT },
{ "DISPLAY", kwDISPLAY },
{ "DISTINCT", kwDISTINCT },
{ "DO", kwDO },
{ "DOMAIN", kwDOMAIN },
{ "DOUBLE", kwDOUBLE },
{ "DROP", kwDROP },
{ "ECHO", kwECHO },
{ "EDIT", kwEDIT },
{ "ELSE", kwELSE },
{ "END", kwEND },
{ "ENTRY_POINT", kwENTRY_POINT },
{ "ESCAPE", kwESCAPE },
{ "EVENT", kwEVENT },
{ "EXCEPTION", kwEXCEPTION },
{ "EXECUTE", kwEXECUTE },
{ "EXISTS", kwEXISTS },
{ "EXIT", kwEXIT },
{ "EXTERN", kwEXTERN },
{ "EXTERNAL", kwEXTERNAL },
{ "EXTRACT", kwEXTRACT },
{ "FALSE", kwFALSE },
{ "FETCH", kwFETCH },              // fb2.0
{ "FILE", kwFILE },
{ "FILTER", kwFILTER },
{ "FIRST", kwFIRST },
{ "FLOAT", kwFLOAT },
{ "FOR", kwFOR },
{ "FOREIGN", kwFOREIGN },
{ "FOUND", kwFOUND },
{ "FREE_IT", kwFREE_IT },
{ "FROM", kwFROM },
{ "FULL", kwFULL },
{ "FUNCTION", kwFUNCTION },
{ "GDSCODE", kwGDSCODE },
{ "GENERATOR", kwGENERATOR },
{ "GEN_ID", kwGEN_ID },
{ "GLOBAL", kwGLOBAL },
{ "GOTO", kwGOTO },
{ "GRANT", kwGRANT },
{ "GROUP", kwGROUP },
{ "GROUP_COMMIT_", kwGROUP_COMMIT_ },
{ "GROUP_COMMIT_WAIT", kwGROUP_COMMIT_WAIT },
{ "HAVING", kwHAVING },
{ "HELP", kwHELP },
{ "HOUR", kwHOUR },
{ "IF", kwIF },
{ "IIF", kwIIF },
{ "IMMEDIATE", kwIMMEDIATE },
{ "IN", kwIN },
{ "INACTIVE", kwINACTIVE },
{ "INDEX", kwINDEX },
{ "INDICATOR", kwINDICATOR },
{ "INIT", kwINIT },
{ "INNER", kwINNER },
{ "INPUT", kwINPUT },
{ "INPUT_TYPE", kwINPUT_TYPE },
{ "INSERT", kwINSERT },
{ "INSERTING", kwINSERTING },
{ "INT", kwINT },
{ "INTEGER", kwINTEGER },
{ "INTO", kwINTO },
{ "IS", kwIS },
{ "ISOLATION", kwISOLATION },
{ "ISQL", kwISQL },
{ "JOIN", kwJOIN },
{ "KEY", kwKEY },
{ "LAST", kwLAST },
{ "LC_MESSAGES", kwLC_MESSAGES },
{ "LC_TYPE", kwLC_TYPE },
{ "LEADING", kwLEADING },          // fb2.0
{ "LEAVE", kwLEAVE },
{ "LEFT", kwLEFT },
{ "LENGTH", kwLENGTH },
{ "LEV", kwLEV },
{ "LEVEL", kwLEVEL },
{ "LIKE", kwLIKE },
{ "LOCK", kwLOCK },
{ "LOGFILE", kwLOGFILE },
{ "LOG_BUF_SIZE", kwLOG_BUF_SIZE },
{ "LONG", kwLONG },
{ "LOWER", kwLOWER },              // fb2.0
{ "MANUAL", kwMANUAL },
{ "MAX", kwMAX },
{ "MAXIMUM", kwMAXIMUM },
{ "MAXIMUM_SEGMENT", kwMAXIMUM_SEGMENT },
{ "MAX_SEGMENT", kwMAX_SEGMENT },
{ "MERGE", kwMERGE },
{ "MIN", kwMIN },
{ "MINIMUM", kwMINIMUM },
{ "MINUTE", kwMINUTE },
{ "MODULE_NAME", kwMODULE_NAME },
{ "MONTH", kwMONTH },
{ "NAMES", kwNAMES },
{ "NATIONAL", kwNATIONAL },
{ "NATURAL", kwNATURAL },
{ "NCHAR", kwNCHAR },
{ "NEXT", kwNEXT },
{ "NO", kwNO },
{ "NOAUTO", kwNOAUTO },
{ "NOT", kwNOT },
{ "NULL", kwNULL },
{ "NULLIF", kwNULLIF },
{ "NULLS", kwNULLS },
{ "NUMERIC", kwNUMERIC },
{ "NUM_LOG_BUFS", kwNUM_LOG_BUFS },
{ "OCTET_LENGTH", kwOCTET_LENGTH },        // fb2.0
{ "OF", kwOF },
{ "ON", kwON },
{ "ONLY", kwONLY },
{ "OPEN", kwOPEN },                        // fb2.0
{ "OPTION", kwOPTION },
{ "OR", kwOR },
{ "ORDER", kwORDER },
{ "OUTER", kwOUTER },
{ "OUTPUT", kwOUTPUT },
{ "OUTPUT_TYPE", kwOUTPUT_TYPE },
{ "OVERFLOW", kwOVERFLOW },
{ "PAGE", kwPAGE },
{ "PAGELENGTH", kwPAGELENGTH },
{ "PAGES", kwPAGES },
{ "PAGE_SIZE", kwPAGE_SIZE },
{ "PARAMETER", kwPARAMETER },
{ "PASSWORD", kwPASSWORD },
{ "PERCENT", kwPERCENT },
{ "PLAN", kwPLAN },
{ "POSITION", kwPOSITION },
{ "POST_EVENT", kwPOST_EVENT },
{ "PRECISION", kwPRECISION },
{ "PREPARE", kwPREPARE },
{ "PRESERVE", kwPRESERVE },
{ "PRIMARY", kwPRIMARY },
{ "PRIVILEGES", kwPRIVILEGES },
{ "PROCEDURE", kwPROCEDURE },
{ "PROTECTED", kwPROTECTED },
{ "PUBLIC", kwPUBLIC },
{ "QUIT", kwQUIT },
{ "RAW_PARTITIONS", kwRAW_PARTITIONS },
{ "READ", kwREAD },
{ "REAL", kwREAL },
{ "RECORD_VERSION", kwRECORD_VERSION },
{ "RECREATE", kwRECREATE },
{ "REFERENCES", kwREFERENCES },
{ "RELEASE", kwRELEASE },
{ "RESERV", kwRESERV },
{ "RESERVING", kwRESERVING },
{ "RESTART", kwRESTART },
{ "RESTRICT", kwRESTRICT },
{ "RETAIN", kwRETAIN },
{ "RETURN", kwRETURN },
{ "RETURNING", kwRETURNING },
{ "RETURNING_VALUES", kwRETURNING_VALUES },
{ "RETURNS", kwRETURNS },
{ "REVOKE", kwREVOKE },
{ "RIGHT", kwRIGHT },
{ "ROLE", kwROLE },
{ "ROLLBACK", kwROLLBACK },
{ "ROWS", kwROWS },                    // fb2.0
{ "ROW_COUNT", kwROW_COUNT },
{ "RUNTIME", kwRUNTIME },
{ "SAVEPOINT", kwSAVEPOINT },
{ "SCALAR_ARRAY", kwSCALAR_ARRAY },
{ "SCHEMA", kwSCHEMA },
{ "SECOND", kwSECOND },
{ "SEGMENT", kwSEGMENT },
{ "SELECT", kwSELECT },
{ "SEQUENCE", kwGENERATOR },
{ "SET", kwSET },
{ "SHADOW", kwSHADOW },
{ "SHARED", kwSHARED },
{ "SHELL", kwSHELL },
{ "SHOW", kwSHOW },
{ "SINGULAR", kwSINGULAR },
{ "SIZE", kwSIZE },
{ "SKIP", kwSKIP },
{ "SMALLINT", kwSMALLINT },
{ "SNAPSHOT", kwSNAPSHOT },
{ "SOME", kwSOME },
{ "SORT", kwSORT },
{ "SQLCODE", kwSQLCODE },
{ "SQLERROR", kwSQLERROR },
{ "SQLWARNING", kwSQLWARNING },
{ "STABILITY", kwSTABILITY },
{ "STARTING", kwSTARTING },
{ "STARTS", kwSTARTS },
{ "STATEMENT", kwSTATEMENT },
{ "STATIC", kwSTATIC },
{ "STATISTICS", kwSTATISTICS },
{ "START", kwSTART },
{ "SUBSTRING", kwSUBSTRING },
{ "SUB_TYPE", kwSUB_TYPE },
{ "SUM", kwSUM },
{ "SUSPEND", kwSUSPEND },
{ "TABLE", kwTABLE },
{ "TEMPORARY", kwTEMPORARY },
{ "TERM", kwTERMINATOR },
{ "TERMINATOR", kwTERMINATOR },
{ "THEN", kwTHEN },
{ "TIES", kwTIES },
{ "TIME", kwTIME },
{ "TIMESTAMP", kwTIMESTAMP },
{ "TO", kwTO },
{ "TRAILING", kwTRAILING },            // fb2.0
{ "TRANSACTION", kwTRANSACTION },
{ "TRANSLATE", kwTRANSLATE },
{ "TRANSLATION", kwTRANSLATION },
{ "TRIGGER", kwTRIGGER },
{ "TRIM", kwTRIM },                    // fb2.0
{ "TRUE", kwTRUE },
{ "TYPE", kwTYPE },
{ "UNCOMMITTED", kwUNCOMMITTED },
{ "UNION", kwUNION },
{ "UNIQUE", kwUNIQUE },
{ "UNKNOWN", kwUNKNOWN },
{ "UPDATE", kwUPDATE },
{ "UPDATING", kwUPDATING },
{ "UPPER", kwUPPER },
{ "USER", kwUSER },
{ "USING", kwUSING },
{ "VALUE", kwVALUE },
{ "VALUES", kwVALUES },
{ "VARCHAR", kwVARCHAR },
{ "VARIABLE", kwVARIABLE },
{ "VARYING", kwVARYING },
{ "VERSION", kwVERSION },
{ "VIEW", kwVIEW },
{ "WAIT", kwWAIT },
{ "WAIT_TIME", kwWAIT_TIME },
{ "WEEKDAY", kwWEEKDAY },
{ "WHEN", kwWHEN },
{ "WHENEVER", kwWHENEVER },
{ "WHERE", kwWHERE },
{ "WHILE", kwWHILE },
{ "WITH", kwWITH },
{ "WORK", kwWORK },
{ "WRITE", kwWRITE },
{ "YEAR", kwYEAR },
{ "YEARDAY", kwYEARDAY },
{ "SIMILAR", kwSIMILAR },
{ "DETERMINISTIC", kwDETERMINISTIC },
{ "OVER", kwOVER },
{ "RETURN", kwRETURN },
{ "SCROLL", kwSCROLL },
{ "SQLSTATE", kwSQLSTATE },
